@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -249,9 +249,9 @@ class AutoMlAsyncClient:
 
             from google.cloud import automl_v1
 
-            def sample_create_dataset():
+            async def sample_create_dataset():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 dataset = automl_v1.Dataset()
@@ -268,7 +268,7 @@ class AutoMlAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -337,7 +337,12 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -365,9 +370,9 @@ class AutoMlAsyncClient:
 
             from google.cloud import automl_v1
 
-            def sample_get_dataset():
+            async def sample_get_dataset():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 request = automl_v1.GetDatasetRequest(
@@ -375,7 +380,7 @@ class AutoMlAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_dataset(request=request)
+                response = await client.get_dataset(request=request)
 
                 # Handle the response
                 print(response)
@@ -447,7 +452,12 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -467,9 +477,9 @@ class AutoMlAsyncClient:
 
             from google.cloud import automl_v1
 
-            def sample_list_datasets():
+            async def sample_list_datasets():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 request = automl_v1.ListDatasetsRequest(
@@ -480,7 +490,7 @@ class AutoMlAsyncClient:
                 page_result = client.list_datasets(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -551,12 +561,20 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListDatasetsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -578,9 +596,9 @@ class AutoMlAsyncClient:
 
             from google.cloud import automl_v1
 
-            def sample_update_dataset():
+            async def sample_update_dataset():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 dataset = automl_v1.Dataset()
@@ -592,7 +610,7 @@ class AutoMlAsyncClient:
                 )
 
                 # Make the request
-                response = client.update_dataset(request=request)
+                response = await client.update_dataset(request=request)
 
                 # Handle the response
                 print(response)
@@ -665,7 +683,12 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -685,14 +708,13 @@ class AutoMlAsyncClient:
         completes, and ``delete_details`` in the
         [metadata][google.longrunning.Operation.metadata] field.
 
-
         .. code-block:: python
 
             from google.cloud import automl_v1
 
-            def sample_delete_dataset():
+            async def sample_delete_dataset():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 request = automl_v1.DeleteDatasetRequest(
@@ -704,7 +726,7 @@ class AutoMlAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -787,7 +809,12 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -821,14 +848,13 @@ class AutoMlAsyncClient:
            in the [response][google.longrunning.Operation.response]
            field when it completes.
 
-
         .. code-block:: python
 
             from google.cloud import automl_v1
 
-            def sample_import_data():
+            async def sample_import_data():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 input_config = automl_v1.InputConfig()
@@ -844,7 +870,7 @@ class AutoMlAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -928,7 +954,12 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -956,14 +987,13 @@ class AutoMlAsyncClient:
         [response][google.longrunning.Operation.response] field when it
         completes.
 
-
         .. code-block:: python
 
             from google.cloud import automl_v1
 
-            def sample_export_data():
+            async def sample_export_data():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 output_config = automl_v1.OutputConfig()
@@ -979,7 +1009,7 @@ class AutoMlAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1061,7 +1091,12 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1089,9 +1124,9 @@ class AutoMlAsyncClient:
 
             from google.cloud import automl_v1
 
-            def sample_get_annotation_spec():
+            async def sample_get_annotation_spec():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 request = automl_v1.GetAnnotationSpecRequest(
@@ -1099,7 +1134,7 @@ class AutoMlAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_annotation_spec(request=request)
+                response = await client.get_annotation_spec(request=request)
 
                 # Handle the response
                 print(response)
@@ -1167,7 +1202,12 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1188,14 +1228,13 @@ class AutoMlAsyncClient:
         are created for it: a global evaluation, and one evaluation for
         each annotation spec.
 
-
         .. code-block:: python
 
             from google.cloud import automl_v1
 
-            def sample_create_model():
+            async def sample_create_model():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 request = automl_v1.CreateModelRequest(
@@ -1207,7 +1246,7 @@ class AutoMlAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1278,7 +1317,12 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1306,9 +1350,9 @@ class AutoMlAsyncClient:
 
             from google.cloud import automl_v1
 
-            def sample_get_model():
+            async def sample_get_model():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 request = automl_v1.GetModelRequest(
@@ -1316,7 +1360,7 @@ class AutoMlAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_model(request=request)
+                response = await client.get_model(request=request)
 
                 # Handle the response
                 print(response)
@@ -1384,7 +1428,12 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1404,9 +1453,9 @@ class AutoMlAsyncClient:
 
             from google.cloud import automl_v1
 
-            def sample_list_models():
+            async def sample_list_models():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 request = automl_v1.ListModelsRequest(
@@ -1417,7 +1466,7 @@ class AutoMlAsyncClient:
                 page_result = client.list_models(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1488,12 +1537,20 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListModelsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1513,14 +1570,13 @@ class AutoMlAsyncClient:
         completes, and ``delete_details`` in the
         [metadata][google.longrunning.Operation.metadata] field.
 
-
         .. code-block:: python
 
             from google.cloud import automl_v1
 
-            def sample_delete_model():
+            async def sample_delete_model():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 request = automl_v1.DeleteModelRequest(
@@ -1532,7 +1588,7 @@ class AutoMlAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1615,7 +1671,12 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1644,16 +1705,16 @@ class AutoMlAsyncClient:
 
             from google.cloud import automl_v1
 
-            def sample_update_model():
+            async def sample_update_model():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 request = automl_v1.UpdateModelRequest(
                 )
 
                 # Make the request
-                response = client.update_model(request=request)
+                response = await client.update_model(request=request)
 
                 # Handle the response
                 print(response)
@@ -1724,7 +1785,12 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1753,14 +1819,13 @@ class AutoMlAsyncClient:
         [response][google.longrunning.Operation.response] field when it
         completes.
 
-
         .. code-block:: python
 
             from google.cloud import automl_v1
 
-            def sample_deploy_model():
+            async def sample_deploy_model():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 request = automl_v1.DeployModelRequest(
@@ -1772,7 +1837,7 @@ class AutoMlAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1845,7 +1910,12 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1877,14 +1947,13 @@ class AutoMlAsyncClient:
         [response][google.longrunning.Operation.response] field when it
         completes.
 
-
         .. code-block:: python
 
             from google.cloud import automl_v1
 
-            def sample_undeploy_model():
+            async def sample_undeploy_model():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 request = automl_v1.UndeployModelRequest(
@@ -1896,7 +1965,7 @@ class AutoMlAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1969,7 +2038,12 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -2001,14 +2075,13 @@ class AutoMlAsyncClient:
         [response][google.longrunning.Operation.response] field when it
         completes.
 
-
         .. code-block:: python
 
             from google.cloud import automl_v1
 
-            def sample_export_model():
+            async def sample_export_model():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 output_config = automl_v1.ModelExportOutputConfig()
@@ -2024,7 +2097,7 @@ class AutoMlAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -2108,7 +2181,12 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -2136,9 +2214,9 @@ class AutoMlAsyncClient:
 
             from google.cloud import automl_v1
 
-            def sample_get_model_evaluation():
+            async def sample_get_model_evaluation():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 request = automl_v1.GetModelEvaluationRequest(
@@ -2146,7 +2224,7 @@ class AutoMlAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_model_evaluation(request=request)
+                response = await client.get_model_evaluation(request=request)
 
                 # Handle the response
                 print(response)
@@ -2214,7 +2292,12 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -2235,9 +2318,9 @@ class AutoMlAsyncClient:
 
             from google.cloud import automl_v1
 
-            def sample_list_model_evaluations():
+            async def sample_list_model_evaluations():
                 # Create a client
-                client = automl_v1.AutoMlClient()
+                client = automl_v1.AutoMlAsyncClient()
 
                 # Initialize request argument(s)
                 request = automl_v1.ListModelEvaluationsRequest(
@@ -2249,7 +2332,7 @@ class AutoMlAsyncClient:
                 page_result = client.list_model_evaluations(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -2343,12 +2426,20 @@ class AutoMlAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListModelEvaluationsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -2363,7 +2454,9 @@ class AutoMlAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-automl",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-automl",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
