@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -61,7 +61,8 @@ class PredictionServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = PredictionServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[PredictionServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -171,10 +172,16 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def model_path(project: str, location: str, model: str,) -> str:
+    def model_path(
+        project: str,
+        location: str,
+        model: str,
+    ) -> str:
         """Returns a fully-qualified model string."""
         return "projects/{project}/locations/{location}/models/{model}".format(
-            project=project, location=location, model=model,
+            project=project,
+            location=location,
+            model=model,
         )
 
     @staticmethod
@@ -187,7 +194,9 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -200,9 +209,13 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -211,9 +224,13 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -222,9 +239,13 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -233,10 +254,14 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -416,7 +441,7 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
         *,
         name: str = None,
         payload: data_items.ExamplePayload = None,
-        params: Sequence[prediction_service.PredictRequest.ParamsEntry] = None,
+        params: Mapping[str, str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -459,7 +484,6 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
         -  A row with column values matching the columns of the model,
            up to 5MB. Not available for FORECASTING ``prediction_type``.
 
-
         .. code-block:: python
 
             from google.cloud import automl_v1
@@ -503,7 +527,7 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
                 This corresponds to the ``payload`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            params (Sequence[google.cloud.automl_v1.types.PredictRequest.ParamsEntry]):
+            params (Mapping[str, str]):
                 Additional domain-specific parameters, any string must
                 be up to 25000 characters long.
 
@@ -585,7 +609,12 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -597,7 +626,7 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
         name: str = None,
         input_config: io.BatchPredictInputConfig = None,
         output_config: io.BatchPredictOutputConfig = None,
-        params: Sequence[prediction_service.BatchPredictRequest.ParamsEntry] = None,
+        params: Mapping[str, str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -623,7 +652,6 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
         -  AutoML Natural Language Sentiment Analysis
         -  AutoML Tables
 
-
         .. code-block:: python
 
             from google.cloud import automl_v1
@@ -681,7 +709,7 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
                 This corresponds to the ``output_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            params (Sequence[google.cloud.automl_v1.types.BatchPredictRequest.ParamsEntry]):
+            params (Mapping[str, str]):
                 Additional domain-specific parameters for the
                 predictions, any string must be up to 25000 characters
                 long.
@@ -824,7 +852,12 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -853,7 +886,9 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-automl",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-automl",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
