@@ -250,8 +250,7 @@ class AutoMlGrpcTransport(AutoMlTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -962,5 +961,9 @@ class AutoMlGrpcTransport(AutoMlTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("AutoMlGrpcTransport",)
