@@ -14,7 +14,13 @@
 # limitations under the License.
 #
 import os
-import mock
+
+# try/except added for compatibility with python < 3.8
+try:
+    from unittest import mock
+    from unittest.mock import AsyncMock
+except ImportError:
+    import mock
 
 import grpc
 from grpc.experimental import aio
@@ -98,20 +104,26 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [PredictionServiceClient, PredictionServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (PredictionServiceClient, "grpc"),
+        (PredictionServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_prediction_service_client_from_service_account_info(client_class):
+def test_prediction_service_client_from_service_account_info(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "automl.googleapis.com:443"
+        assert client.transport._host == ("automl.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -140,23 +152,33 @@ def test_prediction_service_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [PredictionServiceClient, PredictionServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (PredictionServiceClient, "grpc"),
+        (PredictionServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_prediction_service_client_from_service_account_file(client_class):
+def test_prediction_service_client_from_service_account_file(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "automl.googleapis.com:443"
+        assert client.transport._host == ("automl.googleapis.com:443")
 
 
 def test_prediction_service_client_get_transport_class():
@@ -514,7 +536,9 @@ def test_prediction_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -654,10 +678,17 @@ def test_prediction_service_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [prediction_service.PredictRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        prediction_service.PredictRequest,
+        dict,
+    ],
+)
 def test_predict(request_type, transport: str = "grpc"):
     client = PredictionServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -683,7 +714,8 @@ def test_predict_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = PredictionServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -699,7 +731,8 @@ async def test_predict_async(
     transport: str = "grpc_asyncio", request_type=prediction_service.PredictRequest
 ):
     client = PredictionServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -729,13 +762,15 @@ async def test_predict_async_from_dict():
 
 
 def test_predict_field_headers():
-    client = PredictionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = PredictionServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = prediction_service.PredictRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.predict), "__call__") as call:
@@ -749,7 +784,10 @@ def test_predict_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -762,7 +800,7 @@ async def test_predict_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = prediction_service.PredictRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.predict), "__call__") as call:
@@ -778,11 +816,16 @@ async def test_predict_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 def test_predict_flattened():
-    client = PredictionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = PredictionServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.predict), "__call__") as call:
@@ -816,7 +859,9 @@ def test_predict_flattened():
 
 
 def test_predict_flattened_error():
-    client = PredictionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = PredictionServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -892,11 +937,16 @@ async def test_predict_flattened_error_async():
 
 
 @pytest.mark.parametrize(
-    "request_type", [prediction_service.BatchPredictRequest, dict,]
+    "request_type",
+    [
+        prediction_service.BatchPredictRequest,
+        dict,
+    ],
 )
 def test_batch_predict(request_type, transport: str = "grpc"):
     client = PredictionServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -922,7 +972,8 @@ def test_batch_predict_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = PredictionServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -938,7 +989,8 @@ async def test_batch_predict_async(
     transport: str = "grpc_asyncio", request_type=prediction_service.BatchPredictRequest
 ):
     client = PredictionServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -968,13 +1020,15 @@ async def test_batch_predict_async_from_dict():
 
 
 def test_batch_predict_field_headers():
-    client = PredictionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = PredictionServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = prediction_service.BatchPredictRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.batch_predict), "__call__") as call:
@@ -988,7 +1042,10 @@ def test_batch_predict_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1001,7 +1058,7 @@ async def test_batch_predict_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = prediction_service.BatchPredictRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.batch_predict), "__call__") as call:
@@ -1017,11 +1074,16 @@ async def test_batch_predict_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 def test_batch_predict_flattened():
-    client = PredictionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = PredictionServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.batch_predict), "__call__") as call:
@@ -1067,7 +1129,9 @@ def test_batch_predict_flattened():
 
 
 def test_batch_predict_flattened_error():
-    client = PredictionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = PredictionServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1171,7 +1235,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = PredictionServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -1191,7 +1256,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = PredictionServiceClient(client_options=options, transport=transport,)
+        client = PredictionServiceClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -1207,7 +1275,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = PredictionServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1250,10 +1319,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = PredictionServiceClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = PredictionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.PredictionServiceGrpcTransport,)
+    client = PredictionServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.PredictionServiceGrpcTransport,
+    )
 
 
 def test_prediction_service_base_transport_error():
@@ -1293,6 +1380,14 @@ def test_prediction_service_base_transport():
     with pytest.raises(NotImplementedError):
         transport.operations_client
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_prediction_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1304,7 +1399,8 @@ def test_prediction_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.PredictionServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1437,24 +1533,40 @@ def test_prediction_service_grpc_transport_client_cert_source_for_mtls(transport
             )
 
 
-def test_prediction_service_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_prediction_service_host_no_port(transport_name):
     client = PredictionServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="automl.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "automl.googleapis.com:443"
+    assert client.transport._host == ("automl.googleapis.com:443")
 
 
-def test_prediction_service_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_prediction_service_host_with_port(transport_name):
     client = PredictionServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="automl.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "automl.googleapis.com:8000"
+    assert client.transport._host == ("automl.googleapis.com:8000")
 
 
 def test_prediction_service_grpc_transport_channel():
@@ -1462,7 +1574,8 @@ def test_prediction_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.PredictionServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1474,7 +1587,8 @@ def test_prediction_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.PredictionServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1583,12 +1697,16 @@ def test_prediction_service_transport_channel_mtls_with_adc(transport_class):
 
 def test_prediction_service_grpc_lro_client():
     client = PredictionServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
     transport = client.transport
 
     # Ensure that we have a api-core operations client.
-    assert isinstance(transport.operations_client, operations_v1.OperationsClient,)
+    assert isinstance(
+        transport.operations_client,
+        operations_v1.OperationsClient,
+    )
 
     # Ensure that subsequent calls to the property send the exact same object.
     assert transport.operations_client is transport.operations_client
@@ -1596,12 +1714,16 @@ def test_prediction_service_grpc_lro_client():
 
 def test_prediction_service_grpc_lro_async_client():
     client = PredictionServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     transport = client.transport
 
     # Ensure that we have a api-core operations client.
-    assert isinstance(transport.operations_client, operations_v1.OperationsAsyncClient,)
+    assert isinstance(
+        transport.operations_client,
+        operations_v1.OperationsAsyncClient,
+    )
 
     # Ensure that subsequent calls to the property send the exact same object.
     assert transport.operations_client is transport.operations_client
@@ -1612,7 +1734,9 @@ def test_model_path():
     location = "clam"
     model = "whelk"
     expected = "projects/{project}/locations/{location}/models/{model}".format(
-        project=project, location=location, model=model,
+        project=project,
+        location=location,
+        model=model,
     )
     actual = PredictionServiceClient.model_path(project, location, model)
     assert expected == actual
@@ -1653,7 +1777,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "winkle"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = PredictionServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1671,7 +1797,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "scallop"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = PredictionServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1689,7 +1817,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "squid"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = PredictionServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1709,7 +1839,8 @@ def test_common_location_path():
     project = "whelk"
     location = "octopus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = PredictionServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -1734,7 +1865,8 @@ def test_client_with_default_client_info():
         transports.PredictionServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = PredictionServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1743,7 +1875,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = PredictionServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1751,7 +1884,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = PredictionServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
